---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2003-01-16;3
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20030120&codiceRedaz=002G0320&dataVigenza=20251104
dataGU: 20030120
codiceRedaz: 002G0320
dataVigenza: 20251104
---

# Disposizioni ordinamentali in materia di pubblica amministrazione.

La Camera dei deputati ed Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## DISPOSIZIONI IN MATERIA DI PUBBLICHE AMMINISTRAZIONI

### Art. 1. - Alto Commissario per la prevenzione e il contrasto della corruzione e delle altre forme di illecito all'interno della pubblica amministrazione

1. E' istituito l'Alto Commissario per la prevenzione e il contrasto della corruzione e delle altre forme di illecito all'interno della pubblica amministrazione, di seguito denominato "Alto Commissario", alla diretta dipendenza funzionale del Presidente del Consiglio dei ministri.

2. Per le finalita' di cui al comma 1 e' autorizzata la spesa annua massima di 582.000 euro a decorrere dall'anno 2002.

3. Il Governo adotta, su proposta del Ministro per la funzione pubblica, entro sei mesi dalla data di entrata in vigore della presente legge, un regolamento ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, e successive modificazioni, volto a determinare la composizione e le funzioni dell'Alto Commissario, al fine di garantirne l'autonomia e l'efficacia operativa.

4. L'Alto Commissario, che si avvale di un vice Commissario vicario scelto dal Presidente del Consiglio dei ministri, su sua proposta, tra gli appartenenti alle categorie di personale, nell'ambito delle quali e' scelto il Commissario, svolge le proprie funzioni nell'osservanza dei seguenti principi fondamentali:

- a) principio di trasparenza e libero accesso alla documentazione amministrativa, salvo i casi di legittima opposizione del segreto;
- b) libero accesso alle banche dati delle pubbliche amministrazioni;
- c) facolta' di esercitare le proprie funzioni d'ufficio o su istanza delle pubbliche amministrazioni;
- d) obbligo di relazione semestrale al Presidente del Consiglio dei ministri, che riferisce periodicamente ai Presidenti delle Camere;
- e) supporto di un vice Commissario aggiunto, nominato dal Presidente del Consiglio dei ministri su proposta del Commissario, e cinque esperti, tutti scelti tra i magistrati ordinari, amministrativi e contabili e gli avvocati dello Stato, collocati obbligatoriamente fuori ruolo o in aspettativa retribuita dalle rispettive amministrazioni di appartenenza anche in deroga alle norme ed ai criteri che disciplinano i rispettivi ordinamenti, ivi inclusi quelli del personale di cui all'articolo 2, comma 4, del decreto legislativo 3 febbraio 1993, n. 29, se appartenenti ai ruoli degli organi costituzionali, che abbiano prestato non meno di cinque anni di servizio effettivo nell'amministrazione di appartenenza, nonche' altri dipendenti delle amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, in posizione di comando secondo i rispettivi ordinamenti. Per tutto il personale destinato all'ufficio del Commissario il servizio e' equiparato ad ogni effetto a quello prestato presso le amministrazioni di appartenenza;
- f) obbligo di rapporto all'autorita' giudiziaria e alla Corte dei conti nei casi previsti dalla legge;
- g) rispetto delle competenze regionali e delle province autonome di Trento e di Bolzano.

5. All'onere derivante dall'attuazione del presente articolo, pari a 582.000 euro a decorrere dall'anno 2002, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero medesimo.

6. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio. ((13))

------------------ AGGIORNAMENTO (13) Il D.L. 25 giugno 2008, n. 112, convertito, con modificazioni, dalla L. 6 agosto 2008, n. 133 ha disposto (con l'art. 68, comma 6, lettera a)) la soppressione dell'Alto Commissario per la prevenzione ed il contrasto della corruzione e delle altre forme di illecito all'interno della pubblica amministrazione di cui al presente articolo.

### Art. 2. - Commissione per le adozioni internazionali

1. All'articolo 38 della legge 4 maggio 1983, n. 184, come sostituito dall'articolo 3 della legge 31 dicembre 1998, n. 476, sono apportate le seguenti modificazioni:

- a) il comma 2 e' sostituito dal seguente: "2. La Commissione e' composta da: a) un presidente nominato dal Presidente del Consiglio dei ministri nella persona di un magistrato avente esperienza nel settore minorile ovvero di un dirigente dello Stato avente analoga specifica esperienza; b) due rappresentanti della Presidenza del Consiglio dei ministri; c) un rappresentante del Ministero del lavoro e delle politiche sociali; d) un rappresentante del Ministero degli affari esteri; e) un rappresentante del Ministero dell'interno; f) due rappresentanti del Ministero della giustizia; g) un rappresentante del Ministero della salute; h) un rappresentante del Ministero dell'economia e delle finanze; i) un rappresentante del Ministero dell'istruzione, dell'universita' e della ricerca; l) tre rappresentanti della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281; m) tre rappresentanti designati, sulla base di apposito decreto del Presidente del Consiglio dei ministri, da associazioni familiari a carattere nazionale, almeno uno dei quali designato dal Forum delle associazioni familiari";
- b) al comma 4, il secondo e il terzo periodo sono soppressi.

2. Dalle disposizioni di cui al comma 1 non devono derivare nuovi o maggiori oneri a carico del bilancio dello Stato e, a tal fine, sono corrispondentemente rideterminati i trattamenti economici corrisposti, a qualsiasi titolo, ai componenti della Commissione, previsti dal medesimo articolo 38 della citata legge n. 184 del 1983 nel testo vigente anteriormente alla data di entrata in vigore della presente legge.

3. Le spese per l'esecuzione della Convenzione per la tutela dei minori e la cooperazione in materia di adozione internazionale, fatta a L'Aja il 29 maggio 1993, previste dall'articolo 9 della legge 31 dicembre 1998, n. 476, pari a 6.817.231,07 euro, iscritte nell'unita' previsionale di base 3.1.5.1 "Fondo per le politiche sociali" dello stato di previsione del Ministero del lavoro e delle politiche sociali sono trasferite all'unita' previsionale di base 3.1.5.2 "Presidenza del Consiglio dei ministri" dello stato di previsione del Ministero dell'economia e delle finanze, con esclusione della quota di minori entrate, pari a 1.549.370,70 euro, recate dall'articolo 39-quater della legge 4 maggio 1983, n. 184, introdotto dall'articolo 3 della citata legge n. 476 del 1998, e dall'articolo 4 della medesima legge n. 476 del 1998.

### Art. 3. - Soppressione dell'Agenzia per il servizio civile Modifica all'articolo 10 della legge n. 230 del 1998

1. I commi 7, 8 e 9 dell'articolo 10 del decreto legislativo 30 luglio 1999, n. 303, sono abrogati.

2. L'articolo 10, comma 3, della legge 8 luglio 1998, n. 230, e' sostituito dal seguente: "3. La Consulta nazionale per il servizio civile e' composta da non piu' di quindici membri, nominati con decreto del Presidente del Consiglio dei ministri o del Ministro da lui delegato, scelti in maggioranza tra rappresentanti degli enti e delle organizzazioni, pubblici e privati, che impiegano obiettori di coscienza e volontari del servizio civile nazionale ovvero dei loro organismi rappresentativi, nonche' tra rappresentanti degli obiettori di coscienza e dei volontari, delle regioni e delle amministrazioni pubbliche coinvolte".

3. Dall'attuazione del comma 2 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

### Art. 4. - Modifiche al decreto legislativo 30 marzo 2001, n. 165, in materia di formazione del personale delle pubbliche amministrazioni

1. Dopo l'articolo 7 del decreto legislativo 30 marzo 2001, n. 165, e' inserito il seguente: "Art. 7-bis. - (Formazione del personale). - 1. Le amministrazioni di cui all'articolo 1, comma 2, con esclusione delle universita' e degli enti di ricerca, nell'ambito delle attivita' di gestione delle risorse umane e finanziarie, predispongono annualmente un piano di formazione del personale, compreso quello in posizione di comando o fuori ruolo, tenendo conto dei fabbisogni rilevati, delle competenze necessarie in relazione agli obiettivi, nonche' della programmazione delle assunzioni e delle innovazioni normative e tecnologiche. Il piano di formazione indica gli obiettivi e le risorse finanziarie necessarie, nei limiti di quelle, a tale scopo, disponibili, prevedendo l'impiego delle risorse interne, di quelle statali e comunitarie, nonche' le metodologie formative da adottare in riferimento ai diversi destinatari. 2. Le amministrazioni dello Stato, anche ad ordinamento autonomo, nonche' gli enti pubblici non economici, predispongono entro il 30 gennaio di ogni anno il piano di formazione del personale e lo trasmettono, a fini informativi, alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze. Decorso tale termine e, comunque, non oltre il 30 settembre, ulteriori interventi in materia di formazione del personale, dettati da esigenze sopravvenute o straordinarie, devono essere specificamente comunicati alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica e al Ministero dell'economia e delle finanze indicando gli obiettivi e le risorse utilizzabili, interne, statali o comunitarie. Ai predetti interventi formativi si da' corso qualora, entro un mese dalla comunicazione, non intervenga il diniego della Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, di concerto con il Ministero dell'economia e delle finanze. Il Dipartimento della funzione pubblica assicura il raccordo con il Dipartimento per l'innovazione e le tecnologie relativamente agli interventi di formazione connessi all'uso delle tecnologie dell'informazione e della comunicazione".

### Art. 5. - Modifiche all'articolo 102 del testo unico di cui al decreto legislativo n. 267 del 2000

1. All'articolo 102 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, nel comma 2, le parole: "da due esperti" sono sostituite dalle seguenti: "da tre esperti".

2. Dalle disposizioni di cui al comma 1 non devono derivare nuovi o maggiori oneri a carico del bilancio dello Stato e, a tal fine, sono corrispondentemente rideterminati i trattamenti economici corrisposti, a qualsiasi titolo, ai componenti del consiglio di amministrazione dell'Agenzia autonoma per la gestione dell'albo dei segretari comunali e provinciali, previsti dal medesimo articolo 102 del testo unico di cui al decreto legislativo n. 267 del 2000 nel testo vigente anteriormente alla data di entrata in vigore della presente legge.

### Art. 6. - Servizi dei beni culturali

1. All'articolo 10, comma 1, del decreto legislativo 20 ottobre 1998, n. 368, alla lettera b-bis), introdotta dall'articolo 33 della legge 28 dicembre 2001, n. 448, le parole: ", i livelli retributivi minimi per il personale, a prescindere dal contratto di impiego" sono soppresse.

### Art. 7. - Disposizioni in materia di mobilita' del personale delle pubbliche amministrazioni

1. Dopo l'articolo 34 del decreto legislativo 30 marzo 2001, n. 165, e' inserito il seguente: "Art. 34-bis. - (Disposizioni in materia di mobilita' del personale). - 1. Le amministrazioni pubbliche di cui all'articolo 1, comma 2, con esclusione delle amministrazioni previste dall'articolo 3, comma 1, ivi compreso il Corpo nazionale dei vigili del fuoco, prima di avviare le procedure di assunzione di personale, sono tenute a comunicare ai soggetti di cui all'articolo 34, commi 2 e 3, l'area, il livello e la sede di destinazione per i quali si intende bandire il concorso nonche', se necessario, le funzioni e le eventuali specifiche idoneita' richieste. 2. La Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, di concerto con il Ministero dell'economia e delle finanze e le strutture regionali e provinciali di cui all'articolo 34, comma 3, provvedono, entro quindici giorni dalla comunicazione, ad assegnare il personale collocato in disponibilita' ai sensi degli articoli 33 e 34, ovvero interessato ai processi di mobilita' previsti dalle leggi e dai contratti collettivi. Le predette strutture regionali e provinciali, accertata l'assenza negli appositi elenchi di personale da assegnare alle amministrazioni che intendono bandire il concorso, comunicano tempestivamente alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, le informazioni inviate dalle stesse amministrazioni. Entro quindici giorni dal ricevimento della predetta comunicazione, la Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, di concerto con il Ministero dell'economia e delle finanze, provvede ad assegnare alle amministrazioni che intendono bandire il concorso il personale inserito nell'elenco previsto dall'articolo 34, comma 2, nonche' collocato in disponibilita' in forza di specifiche disposizioni normative. 3. Le amministrazioni possono provvedere a organizzare percorsi di qualificazione del personale assegnato ai sensi del comma 2. 4. Le amministrazioni, decorsi due mesi dalla comunicazione di cui al comma 1, possono procedere all'avvio della procedura concorsuale per le posizioni per le quali non sia intervenuta l'assegnazione di personale ai sensi del comma 2. 5. Le assunzioni effettuate in violazione del presente articolo sono nulle di diritto. Restano ferme le disposizioni previste dall'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni".

2. All'articolo 17, comma 1, della legge 28 luglio 1999, n. 266, dopo le parole: "legge 19 maggio 1986, n. 224," sono inserite le seguenti: "nonche' del Corpo nazionale dei vigili del fuoco,".

3. All'articolo 18, comma 9, secondo periodo, del regolamento di cui al decreto del Presidente della Repubblica 4 dicembre 1997, n. 465, dopo le parole: "per le amministrazioni statali" sono inserite le seguenti: "e per gli uffici territoriali del Governo".

4. All'articolo 43, comma 19, della legge 23 dicembre 2000, n. 388, e' aggiunto, in fine, il seguente periodo: "Si applica quanto disposto dagli articoli 33 e 34 del decreto legislativo 30 marzo 2001, n. 165".

### Art. 8. - Contratti individuali dei dirigenti incaricati presso i collegi di revisione degli enti pubblici

1. Alla stipula dei contratti individuali con i dirigenti incaricati presso i collegi di revisione degli enti pubblici ai sensi dell'articolo 19, comma 10, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, provvedono le amministrazioni dello Stato nel cui interesse l'incarico viene svolto.

### Art. 9. - Utilizzazione degli idonei di concorsi pubblici

1. A decorrere dal 2003, fermo restando quanto previsto dall'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni, in materia di programmazione delle assunzioni, con regolamento emanato ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, su proposta del Ministro per la funzione pubblica, di concerto con il Ministro dell'economia e delle finanze, sono stabiliti le modalita' e i criteri con i quali le amministrazioni dello Stato, anche ad ordinamento autonomo, e gli enti pubblici non economici possono ricoprire i posti disponibili, nei limiti della propria dotazione organica, utilizzando gli idonei delle graduatorie di pubblici concorsi approvate da altre amministrazioni del medesimo comparto di contrattazione.

2. Le regioni e le province autonome di Trento e di Bolzano provvedono alle finalita' del presente capo secondo le rispettive competenze previste dai relativi statuti e dalle norme di attuazione.

### Art. 10. - Personale della Presidenza del Consiglio dei ministri

1. Al fine di conseguire risparmi di spesa prevenendo contenzioso giurisdizionale, il personale inquadrato nei ruoli della Presidenza del Consiglio dei ministri in base alle procedure di cui alla legge 23 agosto 1988, n. 400, che, alla data di entrata in vigore della medesima legge, risulti essere in possesso dei requisiti indicati all'articolo 38, comma 4, della citata legge, previa rinuncia espressa ad ogni contenzioso giurisdizionale, puo' essere inquadrato, a domanda e qualora superi l'apposito esame-colloquio, nelle posizioni corrispondenti a quelle conseguite, a seguito della definizione di ricorsi esperiti avverso gli atti di inquadramento, da dipendenti dei medesimi ruoli in possesso degli stessi requisiti. Tale inquadramento decorre, ai fini giuridici, dalla data di entrata in vigore della citata legge n. 400 del 1988, e, ai fini economici, dalla data di entrata in vigore della presente legge.

2. All'onere derivante dal comma 1, pari a 427.000 euro per l'anno 2002 e 437.000 euro a decorrere dall'anno 2003, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

### Art. 11. - Codice unico di progetto degli investimenti pubblici

1. A decorrere dal 1 gennaio 2003, per le finalita' di cui all'articolo 1, commi 5 e 6, della legge 17 maggio 1999, n. 144, e in particolare per la funzionalita' della rete di monitoraggio degli investimenti pubblici, ogni nuovo progetto di investimento pubblico, nonche' ogni progetto in corso di attuazione alla predetta data, e' dotato di un "Codice unico di progetto", che le competenti amministrazioni o i soggetti aggiudicatori richiedono in via telematica secondo la procedura definita dal CIPE.

2. Entro il 30 settembre 2002, il CIPE, acquisito il parere della Conferenza unificata di cui al decreto legislativo 28 agosto 1997, n. 281, disciplina le modalita' e le procedure necessarie per l'attuazione del comma 1.

2-bis. Gli atti amministrativi anche di natura regolamentare adottati dalle Amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, che dispongono il finanziamento pubblico o autorizzano l'esecuzione di progetti di investimento pubblico, sono nulli in assenza dei corrispondenti codici di cui al comma 1 che costituiscono elemento essenziale dell'atto stesso.

2-ter. Le Amministrazioni che emanano atti amministrativi che dispongono il finanziamento pubblico o autorizzano l'esecuzione di progetti di investimento pubblico ((associano negli atti stessi)) il Codice unico di progetto dei progetti autorizzati al programma di spesa con l'indicazione dei finanziamenti concessi a valere su dette misure, della data di efficacia di detti finanziamenti e del valore complessivo dei singoli investimenti. A tal fine il Dipartimento per la programmazione e il coordinamento della politica economica, il ((Dipartimento della Ragioneria)) Generale dello Stato e il Dipartimento per le Politiche di Coesione concordano modalita' per fornire il necessario supporto tecnico per lo svolgimento dell'attivita' di cui al periodo precedente al fine di garantire la corretta programmazione e il monitoraggio della spesa di ciascun programma e dei relativi progetti finanziati.

2-quater. I soggetti titolari di progetti d'investimento pubblico danno notizia, con periodicita' annuale, in apposita sezione dei propri siti web istituzionali, dell'elenco dei progetti finanziati, indicandone il CUP, l'importo totale del finanziamento, le fonti finanziarie, la data di avvio del progetto e lo stato di attuazione finanziario e procedurale.

2-quinquies. Entro il 30 giugno di ogni anno, l'Autorita' politica delegata agli investimenti pubblici ove nominata, con il supporto del Dipartimento per la programmazione e il coordinamento della politica economica, presenta al Comitato Interministeriale per la Programmazione Economica un'informativa sullo stato di attuazione della programmazione degli investimenti pubblici, in base agli esiti dell'applicazione del presente articolo. Entro il medesimo termine, il ((Ministro per il Sud)) e la Coesione Territoriale, con il supporto del Dipartimento per le Politiche di Coesione, presenta al Comitato Interministeriale per la Programmazione Economica un'informativa sullo stato di attuazione della programmazione degli investimenti pubblici finanziati con le risorse nazionali e comunitarie per lo sviluppo e la coesione. A tal fine il Dipartimento della Ragioneria dello Stato mette a disposizione del Dipartimento per la programmazione e il coordinamento della politica economica e del Dipartimento per le Politiche di Coesione, in cooperazione applicativa, i corrispondenti dati rilevati dalle Amministrazioni pubbliche nella banca dati delle Amministrazioni pubbliche di cui alla legge 31 dicembre 2009, n. 196, con le riconciliazioni, ove presenti, con i dati di pagamento del Sistema SIOPE PLUS, di cui all'articolo 14 della legge 31 dicembre 2009, n. 196, e dal sistema della fatturazione elettronica, di cui alla legge ((24 dicembre 2007, n. 244)).

2-sexies. All'attuazione del presente articolo le Amministrazioni provvedono nei limiti delle risorse umane finanziarie e strumentali disponibili allo scopo a legislazione vigente.

### Art. 12. - Personale dell'Ente nazionale di assistenza al volo

1. Entro sei mesi dalla data di entrata in vigore della presente legge, al personale dell'Ente nazionale di assistenza al volo gia' in servizio alla data di entrata in vigore della legge 21 dicembre 1996, n. 665, si applicano le disposizioni previste dagli articoli 30 e 33 del decreto legislativo 30 marzo 2001, n. 165.

### Art. 13. - Modifica all'articolo 10 del decreto-legge 15 gennaio 1991, n. 8

1. All'articolo 10 del decreto-legge 15 gennaio 1991, n. 8, convertito, con modificazioni, dalla legge 15 marzo 1991, n. 82, e successive modificazioni, dopo il comma 2-octies e' aggiunto il seguente: "2-nonies. Con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, vengono stabilite le modalita' di corresponsione dei gettoni di presenza ai componenti della commissione centrale ed al personale chiamato a partecipare con compiti di segreteria e di istruttoria alle riunioni della medesima commissione. All'onere derivante dall'attuazione del presente comma, determinato nella misura massima di 42.000 euro per l'anno 2002 e di 100.000 euro annui a decorrere dall'anno 2003, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero".

### Art. 14. - Disposizione correttiva concernente la compatibilita' della spesa in materia di contrattazione collettiva integrativa

1. All'articolo 40-bis del decreto legislativo 30 marzo 2001, n. 165, introdotto dall'articolo 17, comma 2, della legge 28 dicembre 2001, n. 448, il comma 3 e' sostituito dal seguente: "3. In relazione a quanto previsto dai commi 1 e 2, qualora dai contratti integrativi derivino costi non compatibili con i rispettivi vincoli di bilancio delle amministazioni, si applicano le disposizioni di cui all'articolo 40, comma 3".

## NORME DI SEMPLIFICAZIONE

### Art. 15. - Modifiche al testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445

1. Al testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa, di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, sono apportate le seguenti modificazioni:

- a) dopo l'articolo 19 e' inserito il seguente: "Art. 19-bis.(L). (Disposizioni concernenti la dichiarazione sostitutiva) - 1. La dichiarazione sostitutiva dell'atto di notorieta', di cui all'articolo 19, che attesta la conformita' all'originale di una copia di un atto o di un documento rilasciato o conservato da una pubblica amministrazione, di un titolo di studio o di servizio e di un documento fiscale che deve obbligatoriamente essere conservato dai privati, puo' essere apposta in calce alla copia stessa";
- b) dopo l'articolo 77 e' inserito il seguente: "Art. 77-bis.(L). (Applicazione di norme) - 1. Le disposizioni in materia di documentazione amministrativa contenute nei capi II e III si applicano a tutte le fattispecie in cui sia prevista una certificazione o altra attestazione, ivi comprese quelle concernenti le procedure di aggiudicazione e affidamento di opere pubbliche o di pubblica utilita', di servizi e di forniture, ancorche' regolate da norme speciali, salvo che queste siano espressamente richiamate dall'articolo 78".

## DISPOSIZIONI IN MATERIA DI ENTI LOCALI

### Art. 16. - Modifica al testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, in materia di sanzioni amministrative per le violazioni delle disposizioni dei regolamenti comunali e provinciali

1. Dopo l'articolo 7 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, e' inserito il seguente: "Art. 7-bis. - (Sanzioni amministrative) - 1. Salvo diversa disposizione di legge, per le violazioni delle disposizioni dei regolamenti comunali e provinciali si applica la sanzione amministrativa pecuniaria da 25 euro a 500 euro. 2. L'organo competente a irrogare la sanzione amministrativa e' individuato ai sensi dell'articolo 17 della legge 24 novembre 1981, n. 689".

## NORME IN MATERIA DI ISTRUZIONE, UNIVERSITA' E RICERCA

### Art. 17. - Gestione di fondi

1. Il Ministero dell'istruzione, dell'universita' e della ricerca affida alla Cassa depositi e prestiti la gestione dei fondi relativi alla realizzazione di alloggi e residenze per studenti universitari di cui alla legge 14 novembre 2000, n. 338, corrispondendo a favore della stessa una commissione sulle somme erogate, a valere sui medesimi fondi, nella misura definita dalla convenzione tipo approvata con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con il Ministro dell'economia e delle finanze.

### Art. 18. - Modifiche al decreto legislativo 27 luglio 1999, n. 297

1. Al decreto legislativo 27 luglio 1999, n. 297, sono apportate le seguenti modificazioni:

- a) all'articolo 3, comma 1, lettera a), dopo il numero 2) e' inserito il seguente: "2-bis) le attivita' di assistenza a soggetti individuali, assimilati e associati ai fini della predisposizione di progetti da presentare nell'ambito degli interventi previsti da programmi dell'Unione europea;";
- b) all'articolo 3, comma 1, lettera c), numero 4), dopo le parole: "dottorato di ricerca" sono inserite le seguenti: ", nonche' ad assegni di ricerca di cui all'articolo 51, comma 6, della legge 27 dicembre 1997, n. 449,";
- c) all'articolo 9, comma 2, dopo le parole: "Restano valide fino alla scadenza" sono inserite le seguenti: ", integrate per quanto necessario ai fini della gestione di tutti gli interventi di cui al presente decreto,";
- d) all'articolo 9, comma 3, le parole: "fatto salvo che per la gestione dei contratti stipulati entro la medesima data" sono sostituite dalle seguenti: "fatto salvo che per la gestione dei contratti stipulati, nonche' per le attivita' istruttorie e gestionali di natura economico-finanziaria, comprese la stipula e la gestione dei contratti, relativamente alle domande di agevolazione presentate fino alla data del 31 dicembre 1999 ai sensi degli articoli 4, 5, 6, 7, 9 e 11 del decreto del Ministro dell'universita' e della ricerca scientifica e tecnologica 8 agosto 1997, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 270 del 19 novembre 1997, degli articoli da 8 a 13 della legge 17 febbraio 1982, n. 46, e successive modificazioni, dell'articolo 11 del decreto-legge 16 maggio 1994, n. 299, convertito, con modificazioni, dalla legge 19 luglio 1994, n. 451, e successive modificazioni, limitatamente alle domande presentate nell'esercizio 1997, dell'articolo 14 della legge 24 giugno 1997, n. 196, e successive modificazioni, con esclusivo riferimento all'esercizio 1998, nonche' per la completa dismissione della propria quota di partecipazione al capitale delle societa' di ricerca istituite ai sensi dell'articolo 2, primo comma, lettera d), della citata legge n. 46 del 1982, e successive modificazioni".

### Art. 19. - Disposizioni in materia di enti pubblici di ricerca, ENEA, ISS, ISPESL e ASI

1. Le disposizioni di cui all'articolo 66 del decreto del Presidente della Repubblica 11 luglio 1980, n. 382, e all'articolo 4, comma 5, della legge 19 ottobre 1999, n. 370, si applicano anche nei confronti degli enti di ricerca, dell'Ente per le nuove tecnologie, l'energia e l'ambiente (ENEA), dell'Istituto superiore di sanita' (ISS), dell'Istituto superiore per la prevenzione e la sicurezza del lavoro (ISPESL) e dell'Agenzia spaziale italiana (ASI).

2. Le disposizioni di cui al comma 1-bis dell'articolo 5 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, e successive modificazioni, concernente la concessione di anticipazioni da parte del Ministero degli affari esteri sui finanziamenti erogati per la realizzazione di progetti di cooperazione allo sviluppo alle universita', sono applicate anche a favore degli enti di ricerca, dell'ENEA, dell'ISS, dell'ISPESL e dell'ASI.

### Art. 20. - Disposizioni concernenti il Consiglio nazionale delle ricerche

1. In deroga alle disposizioni della legge 29 ottobre 1984, n. 720, i trasferimenti disposti dal Consiglio nazionale delle ricerche in favore dei propri istituti o di altre strutture fornite di autonomia contabile e di bilancio sono accreditati su appositi conti bancari ad essi intestati presso l'Istituto incaricato del servizio di cassa. Il Consiglio nazionale delle ricerche provvede a tali trasferimenti in relazione all'oggettivo fabbisogno di liquidita' dei suddetti istituti o strutture.

### Art. 21. - Disposizioni in materia di ricerca industriale

1. Al fine di rendere possibile l'attivazione di tutti gli strumenti di intervento nel settore della ricerca industriale previsti dal decreto legislativo 27 luglio 1999, n. 297, e successive modificazioni, e di garantire altresi' il necessario sostegno finanziario ai progetti di ricerca o formazione presentati al Ministero dell'universita' e della ricerca scientifica e tecnologica ai sensi degli articoli 4, 5, 6 e 11 del decreto del Ministro dell'universita' e della ricerca scientifica e tecnologica 8 agosto 1997, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 270 del 19 novembre 1997, in attuazione delle disposizioni di cui agli articoli da 1 a 13 della legge 17 febbraio 1982, n. 46, e successive modificazioni, il Ministro dell'istruzione, dell'universita' e della ricerca e' autorizzato, nell'ambito delle direttive per la ripartizione del Fondo per le agevolazioni alla ricerca di cui all'articolo 6, comma 4, del citato decreto legislativo 27 luglio 1999, n. 297, a riservare annualmente una quota non inferiore al 30 per cento delle complessive disponibilita' del Fondo stesso alla copertura degli oneri derivanti dai progetti di cui alla medesima legge n. 46 del 1982, e successive modificazioni.

### Art. 22. - Disposizione interpretativa

1. Il comma 10 dell'articolo 1 del decreto-legge 12 novembre 2001, n. 402, convertito, con modificazioni, dalla legge 8 gennaio 2002, n. 1, si interpreta nel senso che i diplomi di assistente sociale validi ai fini dell'accesso ai corsi di laurea specialistica, ai master ed agli altri corsi di formazione post-base di cui al decreto del Ministro dell'universita' e della ricerca scientifica e tecnologica 3 novembre 1999, n. 509, sono i diplomi universitari di assistente sociale.

### Art. 23. - Contributo per le iniziative del Comitato italiano per il 2002 Anno Internazionale delle Montagne e collaborazione dell'Istituto nazionale per la ricerca scientifica e tecnologica sulla montagna

1. Per concorrere al finanziamento delle attivita' e iniziative connesse alla celebrazione dell'Anno Internazionale delle Montagne, e' attribuito un contributo speciale di 2 milioni di euro, per l'anno 2002, in favore del "Comitato italiano per il 2002 - Anno Internazionale delle Montagne". Per lo svolgimento dei suoi compiti il Comitato puo' avvalersi della collaborazione dell'Istituto nazionale per la ricerca scientifica e tecnologica sulla montagna.

2. All'onere derivante dall'attuazione del presente articolo, determinato in 2 milioni di euro per l'anno 2002, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

3. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con proprio decreto, le occorrenti variazioni di bilancio.

## DISPOSIZIONI IN MATERIA DI AFFARI ESTERI

### Art. 24. - Modifiche alla legge 21 novembre 1967, n. 1185, in materia di rilascio dei passaporti

1. La lettera b) dell'articolo 3 della legge 21 novembre 1967, n. 1185, e' sostituita dalla seguente: "b) i genitori che, avendo prole minore, non ottengano l'autorizzazione del giudice tutelare; l'autorizzazione non e' necessaria quando il richiedente abbia l'assenso dell'altro genitore, o quando sia titolare esclusivo della potesta' sul figlio;".

2. All'articolo 17 della legge 21 novembre 1967, n. 1185, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) il primo periodo del primo comma e' sostituito dal seguente: "Il passaporto ordinario e' valido per dieci anni";
- b) il terzo comma e' sostituito dal seguente: "Il passaporto ordinario, qualora rilasciato per un periodo inferiore a dieci anni, puo' essere rinnovato, anche prima della scadenza, per periodi complessivamente non superiori a dieci anni dalla data del rilascio";
- c) il quarto comma e' abrogato.

3. L'articolo 28 della legge 21 novembre 1967, n. 1185, e' abrogato.

4. La disposizione di cui al primo periodo del primo comma dell'articolo 17 della legge 21 novembre 1967, n. 1185, come sostituito dalla lettera a) del comma 2 del presente articolo, si applica ai passaporti ordinari rilasciati dopo la data di entrata in vigore della presente legge.

### Art. 25. - Funzionamento dell'Ufficio dell'Autorita' nazionale per l'attuazione della legge sulla proibizione delle armi chimiche

1. Gli incarichi di cui all'articolo 9, comma 4, della legge 18 novembre 1995, n. 496, e successive modificazioni, conferiti agli esperti nominati ai sensi della medesima disposizione, possono essere rinnovati anche dopo la scadenza del primo rinnovo, per la durata di due anni, prorogabile per un periodo ulteriore di due anni.((11a))

-------------- AGGIORNAMENTO (11a) Il D.L. 30 dicembre 2005, n. 273, convertito con modificazioni dalla L. 23 febbraio 2006, n. 51 ha disposto (Con l'art. 23-ter, comma 1) che "Gli incarichi conferiti ai sensi dell'articolo 9, comma 4, della legge 18 novembre 1995, n. 496, e rinnovati ai sensi dell'art. 25 della legge 16 gennaio 2003, n. 3, si intendono rinnovabili alle rispettive scadenze per ulteriori due anni".

### Art. 26. - Costituzione e partecipazione italiana ad associazioni e fondazioni in Italia e all'estero

1. Il Ministero degli affari esteri puo', anche attraverso gli istituti di cultura all'estero, acquisito il parere della Commissione nazionale per la promozione della cultura italiana all'estero di cui all'articolo 4 della legge 22 dicembre 1990, n. 401, costituire o partecipare, d'intesa con il Ministero dell'economia e delle finanze, nei limiti degli ordinari stanziamenti di bilancio destinati agli interventi di promozione culturale all'estero, ad associazioni o fondazioni in Italia e all'estero, finanziate da soggetti privati o enti pubblici con propri apporti di capitale, per la realizzazione di grandi progetti di promozione e cooperazione culturale, nonche' di diffusione e promozione della lingua italiana e delle tradizioni e culture locali. L'atto costitutivo e lo statuto delle associazioni e fondazioni devono prevedere che, in caso di estinzione o scioglimento, il Ministero degli affari esteri partecipa alla divisione dell'attivo patrimoniale in relazione ai propri conferimenti. ((4))

2. Il Governo riferisce sulle iniziative assunte in conformita' alle disposizioni del presente articolo nella relazione annuale al Parlamento di cui all'articolo 3, comma 1, lettera g), della legge 22 dicembre 1990, n. 401.

--------------- AGGIORNAMENTO (4) La L. 24 dicembre 2003, n. 360 ha disposto (con l'art. 12, comma 1) che e' autorizzata la spesa complessiva di euro 1.000.000 per l'anno 2004 per contribuire alla costituzione da parte del Ministero degli affari esteri, nell'ambito delle proprie competenze, di fondazioni che hanno per scopo la promozione dell'immagine dell'Italia nel Mondo, anche in deroga al comma 1, primo periodo, del presente articolo.

## DISPOSIZIONI IN MATERIA DI INNOVAZIONE

### Art. 27. - Disposizioni in materia di innovazione tecnologica nella pubblica amministrazione

1. Nel perseguimento dei fini di maggior efficienza ed economicita' dell'azione amministrativa, nonche' di modernizzazione e sviluppo del Paese, il Ministro per l'innovazione e le tecnologie, nell'attivita' di coordinamento e di valutazione dei programmi, dei progetti e dei piani di azione formulati dalle amministrazioni per lo sviluppo dei sistemi informativi, sostiene progetti di grande contenuto innovativo, di rilevanza strategica, di preminente interesse nazionale, con particolare attenzione per i progetti di carattere intersettoriale, con finanziamenti aggiuntivi a carico e nei limiti del Fondo di cui al comma 2; puo' inoltre promuovere e finanziare progetti ((, anche di carattere internazionale,)) del Dipartimento per l'innovazione e le tecnologie con le medesime caratteristiche.

2. Il Ministro, sentito il Comitato dei Ministri per la societa' dell'informazione, individua i progetti di cui al comma 1, con l'indicazione degli stanziamenti necessari per la realizzazione di ciascuno di essi. Per il finanziamento relativo e' istituito il "Fondo di finanziamento per i progetti strategici nel settore informatico", iscritto in una apposita unita' previsionale di base dello stato di previsione del Ministero dell'economia e delle finanze.

3. Per il finanziamento del Fondo di cui al comma 2 e' autorizzata la spesa di 25.823.000 euro per l'anno 2002, 51.646.000 euro per l'anno 2003 e 77.469.000 euro per l'anno 2004. Al relativo onere si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di conto capitale "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

4. Le risorse di cui all'articolo 29, comma 7, lettera b), secondo periodo, della legge 28 dicembre 2001, n. 448, destinate al finanziamento dei progetti innovativi nel settore informatico, confluiscono nel Fondo di cui al comma 2 e a tal fine vengono mantenute in bilancio per essere versate in entrata e riassegnate al Fondo medesimo.

5. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare con propri decreti le occorrenti variazioni di bilancio.

6. A decorrere dall'anno 2005, l'autorizzazione di spesa puo' essere rifinanziata ai sensi dell'articolo 11, comma 3, lettera f), della legge 5 agosto 1978, n. 468, e successive modificazioni.

7. Il Ministro per l'innovazione e le tecnologie assicura il raccordo con il Ministro per la funzione pubblica relativamente alle innovazioni che riguardano l'ordinamento organizzativo e funzionale delle pubbliche amministrazioni.

8. Entro un anno dalla data di entrata in vigore della presente legge sono emanati uno o piu' regolamenti, ai sensi dell'articolo 117, sesto comma, della Costituzione e dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, per introdurre nella disciplina vigente le norme necessarie ai fini del conseguimento dei seguenti obiettivi:

- a) diffusione dei servizi erogati in via telematica ai cittadini e alle imprese, anche con l'intervento dei privati, nel rispetto dei principi di cui all'articolo 97 della Costituzione e dei provvedimenti gia' adottati;
- b) LETTERA ABROGATA DAL D.LGS. 7 MARZO 2005, N. 82
- c) diffusione dell'uso delle firme elettroniche;
- d) ricorso a procedure telematiche da parte della pubblica amministrazione per l'approvvigionamento di beni e servizi, potenziando i servizi forniti dal Ministero dell'economia e delle finanze attraverso la CONSIP Spa (concessionaria servizi informativi pubblici);
- e) estensione dell'uso della posta elettronica nell'ambito delle pubbliche amministrazioni e dei rapporti tra pubbliche amministrazioni e privati;
- f) generalizzazione del ricorso a procedure telematiche nella contabilita' e nella tesoreria;
- g) alfabetizzazione informatica dei pubblici dipendenti;
- h) impiego della telematica nelle attivita' di formazione dei dipendenti pubblici;
- i) diritto di accesso e di reclamo esperibile in via telematica da parte dell'interessato nei confronti delle pubbliche amministrazioni.

9. I regolamenti di cui al comma 8 sono adottati su proposta congiunta dei Ministri per la funzione pubblica e per l'innovazione e le tecnologie, di concerto con il Ministro dell'economia e delle finanze.

10. All'articolo 29 della legge 28 dicembre 2001, n. 448, sono apportate le seguenti modificazioni:

- a) il comma 6 e' sostituito dal seguente: "6. Con regolamento, da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, entro il 30 giugno 2003, il Governo, su proposta del Ministro dell'economia e delle finanze e del Ministro per la funzione pubblica, di concerto con il Ministro per l'innovazione e le tecnologie, sentite le organizzazioni sindacali per quanto riguarda i riflessi sulla destinazione del personale, procede alla soppressione dell'Autorita' per l'informatica nella pubblica amministrazione e del Centro tecnico di cui all'articolo 17, comma 19, della legge 15 maggio 1997, n. 127, nonche' all'istituzione dell'Agenzia nazionale per l'innovazione tecnologica. L'Agenzia subentra in tutti i rapporti giuridici attivi e passivi dell'Autorita' per l'informatica nella pubblica amministrazione e del Centro tecnico; subentra altresi' nelle funzioni gia' svolte dai predetti organismi, fatte salve quelle attribuite dalla legge al Ministro per l'innovazione e le tecnologie";
- b) al comma 7, lettera b), dopo le parole: "pubblica amministrazione (AIPA)" sono inserite le seguenti: ", fino alla data di entrata in vigore del regolamento di cui al comma 6".

## DISPOSIZIONI IN MATERIA DI DIFESA E DI PUBBLICA SICUREZZA

### Art. 28. - Modifiche all'allegato D annesso al decreto legislativo 28 novembre 1997, n. 464, e successive modificazioni, concernente la riforma strutturale delle Forze armate

1. Al numero 4 dell'allegato D annesso al decreto legislativo 28 novembre 1997, n. 464, e successive modificazioni, e' aggiunto, in fine, il seguente periodo: "Le funzioni in materia di attribuzione degli stipendi agli ufficiali, di cui all'articolo 3, secondo comma, del testo unico di cui al regio decreto 31 dicembre 1928, n. 3458, come sostituito dalla legge 26 febbraio 1960, n. 165, nonche' quelle in materia di cessazione dal servizio, attribuzione e liquidazione del trattamento normale di quiescenza del personale militare e di collocamento a riposo per eta' e liquidazione del trattamento normale di quiescenza del personale civile di cui all'articolo 2, secondo comma, del decreto del Presidente della Repubblica 19 gennaio 1976, pubblicato nella Gazzetta Ufficiale n. 182 del 13 luglio 1976, gia' conferite ai comandanti di regione militare, sono attribuite all'Ispettore logistico dell'Esercito, che le esplica anche a mezzo delega".

### Art. 29. - Disposizioni in materia di acquisti all'estero di materiali per l'Amministrazione della difesa

1. Dopo il comma 1-bis dell'articolo 5 del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, e successive modificazioni, e' inserito il seguente: "1-ter. Il divieto di cui al comma 1 non si applica per gli acquisti eseguiti all'estero dall'Amministrazione della difesa, relativi a macchinari, strumenti e oggetti di precisione che possono essere forniti, con i requisiti tecnici e il grado di perfezione richiesti, soltanto da ditte straniere. Per tali acquisti possono essere concesse anticipazioni di importo non superiore ad un terzo dell'importo complessivo del prezzo contrattuale, previa costituzione di idonea garanzia".

### Art. 30.

((ARTICOLO ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66))

### Art. 31. - Differimento di termine

1. Il termine previsto dall'articolo 3, comma 4, della legge 14 novembre 2000, n. 331, per l'emanazione di uno o piu' decreti legislativi recanti disposizioni integrative e correttive del decreto legislativo 8 maggio 2001, n. 215, e' differito fino al 31 luglio 2003.

### Art. 32.

((ARTICOLO ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66))

### Art. 33.

((ARTICOLO ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66))

### Art. 34. - Beneficio a favore dei congiunti del personale delle Forze armate e delle Forze di polizia e spese sanitarie sostenute dal medesimo personale

1. Le disposizioni previste dall'articolo 1, comma 2, della legge 23 novembre 1998, n. 407, e successive modificazioni, sono estese al coniuge e ai figli superstiti, ovvero ai genitori o ai fratelli conviventi e a carico qualora unici superstiti, del personale delle Forze armate e delle Forze di polizia deceduto o divenuto permanentemente inabile al servizio per effetto di ferite o lesioni di natura violenta riportate nello svolgimento di attivita' operative ((ovvero)) a causa di atti delittuosi commessi da terzi.

2. Le spese sanitarie sostenute dal personale delle Forze armate e delle Forze di polizia per cure relative a ferite e lesioni riportate nello svolgimento di attivita' operative sono anticipate dall'Amministrazione di competenza, nei limiti delle risorse disponibili destinate a tali finalita', su richiesta del Comandante di Corpo o del funzionario responsabile.

### Art. 35. - Modifica all'articolo 1 del decreto-legge 25 maggio 1994, n. 313

1. All'articolo 1, comma 1, del decreto-legge 25 maggio 1994, n. 313, convertito, con modificazioni, dalla legge 22 luglio 1994, n. 460, dopo le parole: "Corpo nazionale dei vigili del fuoco," sono inserite le seguenti: "o del Cassiere del Ministero dell'interno, comunque".

### Art. 36. - Modifica all'articolo 12 del decreto legislativo 28 febbraio 2001, n. 53

1. Al comma 2 dell'articolo 12 del decreto legislativo 28 febbraio 2001, n. 53, le parole: "fatta salva la decorrenza a tutti gli effetti" sono sostituite dalle seguenti: "fatta salva la decorrenza economica".

### Art. 37. - Disposizioni a favore dei congiunti del personale delle Forze di polizia e dell'Arma dei carabinieri

1. All'articolo 6, comma 5, del decreto del Presidente della Repubblica 24 aprile 1982, n. 335, recante ordinamento del personale della Polizia di Stato che espleta funzioni di polizia, e successive modificazioni, ed all'articolo 5, comma 4, del decreto del Presidente della Repubblica 24 aprile 1982, n. 337, recante ordinamento del personale della Polizia di Stato che espleta attivita' tecnico-scientifica o tecnica, e successive modificazioni, dopo le parole: "a causa di azioni criminose di cui all'articolo 82, comma 1, della legge 23 dicembre 2000, n. 388," sono inserite le seguenti: "ovvero per effetto di ferite o lesioni riportate nell'espletamento di servizi di polizia o di soccorso pubblico".

2. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)).

### Art. 38.

Disposizioni a favore dei congiunti del personale del Corpo nazionale dei vigili del fuoco ((e spese sanitarie sostenute dal medesimo personale))

1. Possono essere assunti, a domanda, nel Corpo nazionale dei vigili del fuoco, previo superamento del corso per vigile permanente in prova e nei profili professionali del settore dei servizi amministrativi, tecnici e informatici, fino alla posizione economica B1, il coniuge o un figlio o un fratello convivente del personale appartenente al Corpo nazionale, deceduto o divenuto permanentemente inabile al servizio, per effetto di ferite o lesioni riportate nel corso di eventi verificatisi a decorrere dal 1 gennaio 1999, nell'espletamento delle attivita' istituzionali, purche' siano in possesso dei requisiti previsti per l'accesso e nel limite delle vacanze organiche. Per l'accesso ai profili professionali del settore dei servizi amministrativi, tecnici e informatici, fino alla posizione economica B1, restano comunque ferme le ulteriori disposizioni vigenti in materia.

((1-bis. Le spese sanitarie sostenute dal personale del Corpo nazionale dei vigili del fuoco per cure relative a ferite e lesioni riportate nello svolgimento di servizi operativi e di supporto all'attivita' operativa sono anticipate dall'amministrazione, nei limiti delle risorse disponibili destinate a tali finalita', su richiesta del dirigente della sede di servizio, previo nulla osta del servizio sanitario del Corpo medesimo))

### Art. 39. - Convenzioni in materia di sicurezza

1. Nell'ambito delle direttive impartite dal Ministro dell'interno per il potenziamento dell'attivita' di prevenzione, il Dipartimento della pubblica sicurezza puo' stipulare convenzioni con soggetti pubblici e privati dirette a fornire, con la contribuzione degli stessi soggetti, servizi specialistici, finalizzati ad incrementare la sicurezza pubblica.

2. La contribuzione puo' consistere nella fornitura dei mezzi, attrezzature, locali, nella corresponsione dei costi aggiuntivi sostenuti dal Ministero dell'interno, nella corresponsione al personale impiegato di indennita' commisurate a quelle vigenti per servizi analoghi o determinate con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze e con il Ministro per la funzione pubblica, sentite le organizzazioni sindacali del personale rappresentative sul piano nazionale.

3. Per le convenzioni di cui al comma 1 continuano ad applicarsi le disposizioni dell'articolo 27, comma 2, della legge 23 dicembre 1999, n. 488.

4. L'articolo 18 della legge 7 agosto 1990, n. 232, non si applica alle convenzioni stipulate in attuazione del presente articolo.

4-bis. Nell'ambito delle direttive impartite dal Ministro dell'interno per la semplificazione delle procedure amministrative e per la riduzione degli oneri amministrativi negli uffici di pubblica sicurezza, il Ministero dell'interno puo' altresi', stipulare, senza oneri aggiuntivi per la finanza pubblica, convenzioni con concessionari di pubblici servizi ((dotati di una rete di sportelli capillare su tutto il territorio nazionale, di infrastrutture logistiche e piattaforme tecnologiche integrate, che siano Identity Provider e che abbiano la qualifica di Certification Authority accreditata dall'Agenzia per l'Italia digitale, con esperienza pluriennale nella ricezione, digitalizzazione e gestione delle istanze e dichiarazioni alla pubblica amministrazione e nei servizi finanziari di pagamento,)) per la raccolta e l'inoltro agli uffici dell'Amministrazione dell'interno delle domande, dichiarazioni o atti dei privati indirizzati ai medesimi uffici nonche' per lo svolgimento di altre operazioni preliminari all'adozione dei provvedimenti richiesti e per l'eventuale inoltro, ai privati interessati, dei provvedimenti o atti conseguentemente rilasciati. Con decreto del Ministro dell'interno, si determina l'importo dell'onere a carico dell'interessato al rilascio dei provvedimenti richiesti.

4-ter. Per le finalita' di cui al comma 4-bis, gli incaricati del pubblico servizio, addetti alle procedure definite dalle convenzioni, ((procedono)) all'identificazione degli interessati, ((anche attraverso riconoscimento biometrico e firma grafometrica,)) con l'osservanza delle disposizioni di legge o di regolamento in vigore per gli addetti alla ricezione delle domande, dichiarazioni o atti destinati alle pubbliche amministrazioni.

### Art. 40. - Revisione delle sanzioni disciplinari per il personale della Polizia di Stato e regolamentazione dei relativi procedimenti

1. Il Governo e' delegato ad adottare, entro sei mesi dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi per aggiornare le disposizioni del decreto del Presidente della Repubblica 25 ottobre 1981, n. 737, recante sanzioni disciplinari per il personale dell'Amministrazione di pubblica sicurezza e la regolamentazione dei relativi procedimenti, con l'osservanza dei seguenti principi e criteri direttivi:

- a) esclusione del richiamo orale dal novero delle sanzioni;
- b) esclusione della sanzione della deplorazione, ripartendo le fattispecie fra le sanzioni della pena pecuniaria, aumentata in misura non superiore al doppio, e della sospensione dal servizio;
- c) conseguente rideterminazione delle fattispecie per le quali una sanzione disciplinare puo' essere inflitta, anche in relazione alla mutata articolazione del trattamento economico e tenuto conto delle specifiche esigenze disciplinari;
- d) adeguamento delle disposizioni concernenti la sospensione cautelare dal servizio e la destituzione con riguardo alle vigenti disposizioni processuali penali ed a quelle della legge 27 marzo 2001, n. 97;
- e) rideterminazione degli organi competenti ad irrogare la sanzione, a decidere in sede di riesame ed a svolgere gli accertamenti necessari in relazione alla mutata disciplina delle articolazioni dirigenziali della Polizia di Stato e delle rispettive competenze, nonche' di quelle del Capo della polizia-direttore generale della pubblica sicurezza;
- f) aggiornamento delle disposizioni concernenti il procedimento disciplinare, con criteri di semplificazione e accelerazione delle procedure, prevedendo, per le sanzioni piu' gravi della pena pecuniaria, un procedimento in contraddittorio davanti ad un organo collegiale, con distinzione dei ruoli fra l'organo che sostiene la contestazione e la difesa, nonche' la rideterminazione, con le medesime finalita' di semplificazione e accelerazione dei procedimenti, della composizione degli organi collegiali, anche relativamente alla partecipazione sindacale;
- g) previsione dei casi, delle modalita' e degli effetti della riapertura del procedimento disciplinare, nonche' della riabilitazione;
- h) previsione delle occorrenti disposizioni transitorie anche per i procedimenti pendenti alla data di entrata in vigore dei decreti legislativi di cui al presente comma.

2. I decreti legislativi di cui al comma 1 possono anche prevedere l'abrogazione del citato decreto del Presidente della Repubblica n. 737 del 1981, previa riproduzione delle disposizioni ivi contenute coerenti con i principi ed i criteri di cui al medesimo comma 1.

3. Gli schemi dei decreti legislativi di cui al comma 1 sono trasmessi alle organizzazioni sindacali rappresentative a livello nazionale del personale della Polizia di Stato, che esprimono il parere nei successivi venti giorni; gli schemi medesimi, unitamente ai predetti pareri pervenuti entro il termine, sono trasmessi alla Camera dei deputati e al Senato della Repubblica per il parere delle Commissioni parlamentari competenti per materia, che si esprimono entro trenta giorni dalla data di assegnazione.

4. Disposizioni correttive dei decreti legislativi di cui al comma 1, nel rispetto dei principi, dei criteri direttivi, nonche' delle procedure stabiliti dal presente articolo, possono essere adottate, con uno o piu' decreti legislativi, entro il 31 dicembre 2003.

## DISPOSIZIONI IN MATERIA DI COMUNICAZIONI

### Art. 41. - Tecnologie delle comunicazioni

1. Nell'ambito dell'attivita' del Ministero delle comunicazioni nel campo dello sviluppo delle tecnologie delle comunicazioni e dell'informazione, nonche' della sicurezza delle reti e della tutela delle comunicazioni, l'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione, organo tecnico-scientifico del Ministero delle comunicazioni, continua a svolgere compiti di studio e ricerca scientifica, anche mediante convenzioni con enti ed istituti di ricerca specializzati nel settore delle poste e delle comunicazioni, di predisposizione della normativa tecnica, di certificazione e di omologazione di apparecchiature e sistemi, di formazione del personale del Ministero e di altre organizzazioni pubbliche e private sulla base dell'articolo 12, comma 1, lettera b), del decreto-legge 1 dicembre 1993, n. 487, convertito, con modificazioni, dalla legge 29 gennaio 1994, n. 71. Presso l'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione opera la Scuola superiore di specializzazione in telecomunicazioni ai sensi del regio decreto 19 agosto 1923, n. 2483, e successive modificazioni.

2. Per un efficace ed efficiente svolgimento dei compiti di cui al comma 1, all'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione e' attribuita autonomia scientifica, organizzativa, amministrativa e contabile nei limiti stabiliti dalla legge. I finanziamenti che l'Istituto riceve per effettuare attivita' di ricerca sono versati all'entrata del bilancio dello Stato per essere successivamente riassegnati, con decreto del Ministro dell'economia e delle finanze, allo stato di previsione del Ministero delle comunicazioni - centro di responsabilita' amministrativa "Istituto superiore delle comunicazioni e delle tecnologie dell'informazione" e destinati all'espletamento delle attivita' di ricerca. L'Istituto e' sottoposto al controllo della Corte dei conti, ai sensi dell'articolo 3, comma 4, della legge 14 gennaio 1994, n. 20, e successive modificazioni, e al potere di indirizzo e vigilanza del Ministero delle comunicazioni.

3. Dalla data di entrata in vigore della presente legge il Consiglio superiore tecnico delle poste e delle telecomunicazioni acquista la denominazione di Consiglio superiore delle comunicazioni ed assume tra le proprie attribuzioni quelle riconosciute in base all'articolo 1, comma 24, della legge 31 luglio 1997, n. 249, al Forum permanente per le comunicazioni, che e' conseguentemente soppresso e nella cui dotazione finanziaria il Consiglio succede. Trascorsi trenta giorni dalla data di entrata in vigore della presente legge, i componenti del Consiglio cessano dalla carica. Il Consiglio superiore delle comunicazioni e' organo consultivo del Ministero delle comunicazioni con compiti di proposta nei settori di competenza del Ministero. Con regolamento da emanare entro quattro mesi dalla data di entrata in vigore della presente legge, su proposta del Ministro delle comunicazioni, di concerto con il Ministro dell'economia e delle finanze, ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, si provvede al riordinamento del Consiglio.

4. Il Ministero delle comunicazioni, anche attraverso i propri organi periferici, esercita la vigilanza sui tetti di radiofrequenze compatibili con la salute umana anche a supporto degli organi indicati dall'articolo 14 della legge 22 febbraio 2001, n. 36, ferme restando le competenze del Ministero della salute.

5. La Fondazione Ugo Bordoni e' riconosciuta istituzione di alta cultura e ricerca con lo scopo di promuovere l'innovazione, lo sviluppo tecnologico del Paese e l'alta formazione tecnologica, favorendo lo sviluppo del sistema produttivo nazionale, ed e' sottoposta alla vigilanza del Ministero delle imprese e del made in Italy. La Fondazione e' un ente finalizzato alla ricerca, all'innovazione tecnologica e alla prestazione di servizi e coadiuva operativamente il Ministero delle imprese e del made in Italy e altre amministrazioni pubbliche nella soluzione organica ed interdisciplinare di problematiche di carattere scientifico, tecnico, economico, finanziario, gestionale, normativo e regolatorio connesse alle attivita' del Ministero e delle amministrazioni pubbliche. Per il perseguimento della propria missione la Fondazione pianifica, programma, esegue e valuta, anche utilizzando e valorizzando i laboratori del Ministero, attivita' di studio e ricerca nel campo delle reti e sistemi di telecomunicazioni di nuova generazione, delle tecnologie emergenti, dell'economia dei dati e del business e management. La Fondazione collabora attivamente con altri enti pubblici nazionali di ricerca, con i centri di competenza ad alta specializzazione e con la rete territoriale del Ministero delle imprese e del made in Italy, al fine di razionalizzare le attivita' legate ai processi di trasformazione digitale, canalizzare le risorse sulla base della domanda e massimizzare le ricadute sul tessuto imprenditoriale. La Fondazione, nella sua missione di promozione dello sviluppo ((tecnologico del Paese, puo')) instaurare rapporti con le Universita', con enti pubblici e privati, con le imprese, sia a livello nazionale che internazionale. La Fondazione partecipa attivamente a progetti di ricerca finanziati dall'Unione europea, organizza corsi e seminari sulle tecnologie di frontiera, pubblica su riviste scientifiche di settore i propri risultati e partecipa a convegni e conferenze sia nazionali che internazionali. La Fondazione, su richiesta dell'Autorita' per le garanzie nelle comunicazioni ovvero di altre Autorita' amministrative indipendenti, svolge attivita' di ricerca ed approfondimento su argomenti di carattere tecnico, economico e regolatorio. Le modalita' di collaborazione con il Ministero, con le altre amministrazioni pubbliche e con l'Autorita' per le garanzie nelle comunicazioni e altre Autorita' amministrative indipendenti sono stabilite, nei limiti delle disponibilita' delle amministrazioni, attraverso apposite convenzioni, predisposte sulla base di atti che stabiliscono le condizioni anche economiche cui la Fondazione Ugo Bordoni e' tenuta ad attenersi nell'assolvere agli incarichi ad essa affidati. Al finanziamento della Fondazione lo Stato contribuisce mediante un contributo annuo per ciascuno degli anni 2002, 2003 e 2004 di 5.165.000 euro per spese di investimento relative alle attivita' di ricerca. Al relativo onere si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di conto capitale "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero delle comunicazioni. Prosegue senza soluzione di continuita', rimanendo confermato, il regime convenzionale tra il Ministero delle comunicazioni e la Fondazione Ugo Bordoni, di cui all'atto stipulato in data 7 marzo 2001, recante la disciplina delle reciproche prestazioni relative alle attivita' di collaborazione e la regolazione dei conseguenti rapporti. Nell'interesse generale alla tutela dell'ambiente e della salute pubblica, la Fondazione Ugo Bordoni realizza altresi' la rete di monitoraggio dei livelli di campo elettromagnetico a livello nazionale, a valere sui fondi di cui all'articolo 112 della legge 23 dicembre 2000, n. 388, secondo le modalita' stabilite da apposita convenzione. (8)

6. Lo statuto, l'organizzazione e i ruoli organici della Fondazione Ugo Bordoni sono ridefiniti in coerenza con le attivita' indicate al comma 5 e con la finalita' ((prevalente e specifica)) di ricerca e assistenza tecnica di alto profilo in favore del Ministero delle imprese e del made in Italy, di altre amministrazioni pubbliche, nonche' delle autorita' amministrative indipendenti. Lo statuto, da approvare con ((decreto del Ministro)) delle imprese e del made in Italy, disciplina i compiti e la struttura organizzativa della Fondazione, ne individua le categorie di partecipanti, gli organi di amministrazione e scientifici, le modalita' della loro elezione e i relativi poteri, la loro durata, gli ambiti di attivita' e i controlli di gestione e di risultato. La Fondazione sostiene, d'intesa con le universita', l'attivazione di almeno 1 borsa di dottorato all'anno per ciascuna delle attivita' di cui al comma 5. I dipendenti della Fondazione risultanti in esubero in base alla nuova organizzazione, e comunque fino ad un massimo di 80 unita', possono chiedere di essere immessi, anche in soprannumero, nel ruolo dell'Istituto superiore delle comunicazioni e delle tecnologie dell'informazione e del Ministero delle comunicazioni, al quale accedono con procedure concorsuali, secondo criteri e modalita' da definire con decreto del Ministro delle comunicazioni, di concerto con il Ministro per la funzione pubblica. Al loro inquadramento si provvede nei posti e con le qualifiche professionali analoghe a quelle rivestite. Al personale immesso compete il trattamento economico spettante agli appartenenti alla qualifica in cui ciascun dipendente e' inquadrato, senza tenere conto dell'anzianita' giuridica ed economica maturata con il precedente rapporto. Per le finalita' di cui al presente comma, e' autorizzata la spesa annua massima di 4.648.000 euro a decorrere dall'anno 2002, cui si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero delle comunicazioni. I dipendenti che hanno presentato domanda di inquadramento possono essere mantenuti in servizio presso la Fondazione fino al completamento delle procedure concorsuali.

7. Al fine di incentivare lo sviluppo della radiodiffusione televisiva in tecnica digitale su frequenze terrestri, in aggiunta a quanto gia' previsto dal decreto-legge 23 gennaio 2001, n. 5, convertito, con modificazioni, dalla legge 20 marzo 2001, n. 66, il Ministero delle comunicazioni promuove attivita' di sperimentazione di trasmissioni televisive digitali terrestri e di servizi interattivi, con particolare riguardo alle applicazioni di carattere innovativo nell'area dei servizi pubblici e dell'interazione tra i cittadini e le amministrazioni dello Stato, avvalendosi della riserva di frequenze di cui all'articolo 2, comma 6, lettera d), della legge 31 luglio 1997, n. 249. Tali attivita' sono realizzate, sotto la vigilanza del Ministero delle comunicazioni e dell'Autorita' per le garanzie nelle comunicazioni, con la supervisione tecnica della Fondazione Ugo Bordoni attraverso convenzioni da stipulare tra la medesima Fondazione e soggetti abilitati alla sperimentazione ai sensi del citato decreto-legge n. 5 del 2001, convertito, con modificazioni, dalla legge n. 66 del 2001, e della deliberazione n. 435/01/CONS dell'Autorita' per le garanzie nelle comunicazioni del 15 novembre 2001, pubblicata nel supplemento ordinario alla Gazzetta Ufficiale n. 284 del 6 dicembre 2001, sulla base di progetti da questi presentati. Fino alla data di entrata in vigore del provvedimento previsto dall'articolo 29 della citata deliberazione n. 435/01/CONS, per le predette attivita' di sperimentazione sono utilizzate, su base non interferenziale, le frequenze libere o disponibili.

8. All'articolo 2-bis, comma 10, del decreto-legge 23 gennaio 2001, n. 5, convertito, con modificazioni, dalla legge 20 marzo 2001, n. 66, dopo le parole: "sono rilasciate dal Ministero delle comunicazioni" sono aggiunte le seguenti: "che esercita la vigilanza e il controllo sull'assolvimento degli obblighi derivanti anche da quelle rilasciate dall'Autorita' per le garanzie nelle comunicazioni".

9. Le imprese di radiodiffusione sonora e televisiva in ambito locale che alla data di entrata in vigore della presente legge risultino debitrici per canoni di concessione per l'esercizio di attivita' di radiodiffusione dovuti fino al 31 dicembre 1999 possono definire la propria posizione debitoria, senza applicazione di interessi, mediante pagamento di quanto dovuto, da effettuarsi entro novanta giorni dalla comunicazione alle interessate da parte del Ministero delle comunicazioni, in un'unica soluzione se l'importo e' inferiore ad euro 5.000, ovvero in un numero massimo di cinque rate mensili di ammontare non inferiore ad euro 2.000, con scadenza a partire dal trentesimo giorno successivo alla data di ricevimento della comunicazione, se l'importo e' pari o superiore ad euro 5.000.

--------------- AGGIORNAMENTO (8) Il D.L. 14 marzo 2005, n. 35, convertito con modificazioni dalla L. 14 maggio 2005, n. 80, ha disposto (con l'art. 7, comma 2) che il contributo dello Stato alla fondazione Ugo Bordoni previsto dal comma 5 del presente articolo, e' rinnovato, per il triennio 2005-2007 per l'importo di 5.165.000 euro annui. La fondazione invia, entro il 31 marzo di ogni anno, una relazione al Governo e alle competenti Commissioni parlamentari nella quale da' conto delle attivita' svolte nell'anno precedente.

## DISPOSIZIONI IN MATERIA DI TUTELA DELLA SALUTE

### Art. 42. - Delega per la trasformazione degli istituti di ricovero e cura a carattere scientifico in fondazioni

1. Il Governo e' delegato ad adottare, su proposta del Ministro della salute, d'intesa con il Ministro per la funzione pubblica e con il Ministro dell'economia e delle finanze, entro nove mesi dalla data di entrata in vigore della presente legge, un decreto legislativo recante norme per il riordino della disciplina degli istituti di ricovero e cura a carattere scientifico di diritto pubblico, di cui al decreto legislativo 30 giugno 1993, n. 269, e successive modificazioni, sulla base dei seguenti principi e criteri direttivi:

- a) prevedere e disciplinare, nel rispetto delle attribuzioni delle regioni e delle province autonome di Trento e di Bolzano, le modalita' e le condizioni attraverso le quali il Ministro della salute, d'intesa con la regione interessata, possa trasformare gli istituti di ricovero e cura a carattere scientifico di diritto pubblico, esistenti alla data di entrata in vigore della presente legge, in fondazioni di rilievo nazionale, aperte alla partecipazione di soggetti pubblici e privati e sottoposte alla vigilanza del Ministero della salute e del Ministero dell'economia e delle finanze, ferma restando la natura pubblica degli istituti medesimi;
- b) prevedere che i nuovi enti adeguino la propria organizzazione al principio di separazione tra le funzioni di indirizzo e controllo, da un lato, e gestione e attuazione dall'altro, garantendo, nell'organo di indirizzo, composto dal consiglio di amministrazione e dal presidente eletto dal consiglio di amministrazione, la presenza maggioritaria di membri designati dalle istituzioni pubbliche, Ministero della salute, regioni e comuni, con rappresentanza paritetica del Ministero della salute e della regione interessata, e assicurando che la scelta di tutti i componenti del consiglio sia effettuata sulla base di idonei requisiti di professionalita' e onorabilita', periodicamente verificati; dell'organo di gestione fanno parte il direttore generale-amministratore delegato, nominato dal consiglio di amministrazione, e il direttore scientifico responsabile della ricerca, nominato dal Ministero della salute, sentita la regione interessata; ((10))
- c) trasferire ai nuovi enti, in assenza di oneri, il patrimonio, i rapporti attivi e passivi e il personale degli istituti trasformati. Il personale gia' in servizio all'atto della trasformazione puo' optare per un contratto di lavoro di diritto privato, fermi restando, in ogni caso, i diritti acquisiti;
- d) individuare, nel rispetto della programmazione regionale, misure idonee di collegamento e sinergia con le altre strutture di ricerca e di assistenza sanitaria, pubbliche e private, e con le universita', al fine di elaborare e attuare programmi comuni di ricerca, assistenza e formazione;
- e) prevedere strumenti che valorizzino e tutelino la proprieta' dei risultati scientifici, ivi comprese la costituzione e la partecipazione ad organismi ed enti privati, anche aventi scopo di lucro, operanti nel settore della ricerca biomedica e dell'industria, con modalita' atte a salvaguardare la natura no-profit delle fondazioni;
- f) prevedere che il Ministro della salute assegni a ciascuna fondazione, o a fondazioni aggregate a rete, diversi e specifici progetti finalizzati di ricerca, anche fra quelli proposti dalla comunita' scientifica, sulla base dei quali aggregare scienziati e ricercatori considerando la necessita' di garantire la qualita' della ricerca e valorizzando le specificita' scientifiche gia' esistenti o nelle singole fondazioni ovvero nelle singole realta' locali;
- g) disciplinare le modalita' attraverso le quali applicare i principi di cui al presente articolo agli istituti di ricovero e cura a carattere scientifico di diritto privato, salvaguardandone l'autonomia giuridico-amministrativa;
- h) disciplinare i rapporti di collaborazione con ricercatori e scienziati su progetti specifici, anche di altri enti e strutture, caratterizzati da flessibilita' e temporaneita' e prevedere modalita' di incentivazione, anche attraverso la collaborazione con gli enti di cui alla lettera e);
- i) disciplinare le modalita' attraverso le quali le fondazioni, nel rispetto degli scopi, dei programmi e degli indirizzi deliberati dal consiglio di amministrazione, possono concedere ad altri soggetti, pubblici e privati, compiti di gestione, anche di assistenza sanitaria, in funzione della migliore qualita' e maggiore efficienza del servizio reso;
- l) prevedere che le erogazioni liberali da parte di soggetti privati verso i nuovi enti di diritto privato avvengano in regime di esenzione fiscale;
- m) regolamentare i criteri generali per il riconoscimento delle nuove fondazioni e le ipotesi e i procedimenti per la revisione e la eventuale revoca dei riconoscimenti gia' concessi, sulla base di una programmazione nazionale riferita ad ambiti disciplinari specifici secondo criteri di qualita' ed eccellenza;
- n) prevedere, in caso di estinzione, la devoluzione del patrimonio in favore di altri enti pubblici disciplinati dal presente articolo aventi analoghe finalita';
- o) istituire, senza nuovi o maggiori oneri a carico del bilancio dello Stato, con contestuale soppressione di organi collegiali aventi analoghe funzioni tecnico-consultive nel settore della ricerca sanitaria, presso il Ministero della salute un organismo indipendente, con il compito di sovrintendere alla ricerca biomedica pubblica e privata, composto da esperti altamente qualificati in ambiti disciplinari diversi, espressione della comunita' scientifica nazionale e internazionale e delle istituzioni pubbliche centrali e regionali, con compiti di consulenza e di supporto tecnico;
- p) prevedere che gli istituti di ricovero e cura a carattere scientifico di diritto pubblico, non trasformati ai sensi della lettera a), adeguino la propria organizzazione e il proprio funzionamento ai principi, in quanto applicabili, di cui alle lettere d), e), h) e n), nonche' al principio di separazione fra funzioni di cui alla lettera b), garantendo che l'organo di indirizzo sia composto da soggetti designati per la meta' dal Ministro della salute e per l'altra meta' dal presidente della regione, scelti sulla base di requisiti di professionalita' e di onorabilita', periodicamente verificati, e dal presidente dell'istituto, nominato dal Ministro della salute, e che le funzioni di gestione siano attribuite a un direttore generale nominato dal consiglio di amministrazione, assicurando comunque l'autonomia del direttore scientifico, nominato dal Ministro della salute, sentito il presidente della regione interessata. ((10))

2. Sullo schema di decreto legislativo di cui al comma 1 il Governo acquisisce il parere della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, che si esprime entro quaranta giorni dalla richiesta. Il Governo acquisisce altresi' il parere delle competenti Commissioni parlamentari, che deve essere espresso entro quarantacinque giorni dalla trasmissione dello schema di decreto. Decorsi inutilmente i termini predetti, il decreto legislativo e' emanato anche in mancanza dei pareri.

3. L'attuazione della delega di cui al comma 1 non comporta nuovi o maggiori oneri a carico della finanza pubblica.

-------------- AGGIORNAMENTO (10) La Corte costituzionale, con sentenza 23 giugno-7 luglio 2005, n. 270 (in G.U. 1a s.s. 13/7/2005, n. 28) ha disposto l'illegittimita' costituzionale del comma 1 del presente articolo lettera b) "limitatamente alle parole Ministero della salute, regioni e comuni, con rappresentanza paritetica del Ministero della salute e della regione interessata" e lettera p) "limitatamente alle parole designati per la meta' dal Ministro della salute e per l'altra meta' dal Presidente della Regione" nonche' con riferimento al presidente dell'istituto, alle parole "nominato dal Ministro della salute".

### Art. 43. - Organizzazione a rete di istituti di ricovero e cura a carattere scientifico dedicati a particolari discipline

1. Al fine di favorire la ricerca nazionale e internazionale e poter acquisire risorse anche a livello comunitario, il Ministro della salute, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, individua, con proprio decreto, l'organizzazione a rete degli istituti di ricovero e cura a carattere scientifico dedicati a particolari discipline.

### Art. 44. - Modifica all'articolo 1 della legge 8 febbraio 2001, n. 12

1. All'articolo 1, comma 1, della legge 8 febbraio 2001, n. 12, la lettera d) e' abrogata. A decorrere dalla data di entrata in vigore della presente legge, riacquistano efficacia le previsioni di cui agli articoli 46, 47 e 48 del testo unico delle leggi in materia di disciplina degli stupefacenti e sostanze psicotrope, prevenzione, cura e riabilitazione dei relativi stati di tossicodipendenza, di cui al decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, nel testo vigente prima della data di entrata in vigore della citata legge n. 12 del 2001.

### Art. 45. - Partecipazione finanziaria dei privati in materia sanitaria

1. Per la realizzazione della comunicazione istituzionale in materia sanitaria il Ministero della salute puo' avvalersi anche della partecipazione finanziaria di qualificate aziende private operanti nei settori commerciali ed economici nonche' nel settore della comunicazione e dell'informazione, assicurando alle medesime gli effetti derivanti, in termini di ritorno di immagine, dal loro coinvolgimento nelle peculiari tematiche di utilita' sociale dirette alla promozione della salute.

2. Per la realizzazione della comunicazione istituzionale in materia sanitaria, di cui al comma 1, si applicano le disposizioni della legge 7 giugno 2000, n. 150.

3. Con decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, da adottare ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, sono disciplinati i criteri, le forme, le condizioni e le modalita' della partecipazione di cui al comma 1, assicurando prioritariamente l'inesistenza di situazioni di conflitto di interessi, diretto o indiretto, tra i soggetti privati finanziatori e le finalita' e il contenuto della comunicazione istituzionale di cui al medesimo comma 1.

### Art. 46. - Semplificazione in materia di sedi farmaceutiche

1. I farmacisti che gestiscono in via provvisoria una sede farmaceutica rurale o urbana, ai sensi dell'articolo 129 del testo unico delle leggi sanitarie, di cui al regio decreto 27 luglio 1934, n. 1265, e successive modificazioni, nonche' i farmacisti a cui e' stata attribuita la gestione provvisoria, nel rispetto dell'articolo 1, comma 2, della legge 16 marzo 1990, n. 48, anche se hanno superato il limite di eta' di cui all'articolo 4, comma 2, della legge 8 novembre 1991, n. 362, hanno diritto a conseguire per una sola volta la titolarita' della farmacia, purche' alla data di entrata in vigore della presente legge risultino assegnatari della gestione provvisoria da almeno due anni e non sia stata pubblicata la graduatoria del concorso per l'assegnazione della relativa sede farmaceutica.

2. E' escluso dal beneficio di cui al comma 1 il farmacista che, alla data di entrata in vigore della presente legge, abbia gia' trasferito la titolarita' di altra farmacia da meno di dieci anni ai sensi del quarto comma dell'articolo 12 della legge 2 aprile 1968, n. 475, nonche' il farmacista che abbia gia' ottenuto, da meno di dieci anni, altri benefici o sanatorie.

3. Le domande devono pervenire, a pena di decadenza, alle regioni e alle province autonome di Trento e di Bolzano entro sessanta giorni dalla data di entrata in vigore della presente legge.

4. L'accertamento dei requisiti e delle condizioni previste dai commi 1, 2 e 3 e' effettuato entro un mese dalla presentazione delle domande. ((12))

--------------- AGGIORNAMENTO (12) la Corte costituzionale, con sentenza 6-10 marzo 2006, n. 87 (in G.U. 1a s.s. 15/3/2006, n. 11) ha disposto l'illegittimita' costituzionale del presente art. 46.

### Art. 47. - Istituto superiore di sanita'

1. All'Istituto superiore di sanita' e' estesa dal 1 gennaio 2003 la disciplina contenuta nell'articolo 1, comma 93, della legge 23 dicembre 1996, n. 662, e successive modificazioni, sostituendosi il Ministro della salute al Ministro dell'istruzione, dell'universita' e della ricerca nella effettuazione del concerto.

2. All'onere derivante dall'attuazione del comma 1, determinato in 1.136.205 euro annui, si provvede, a decorrere dal 2003, mediante corrispondente riduzione delle proiezioni per gli anni 2003 e 2004 dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero della salute. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

### Art. 48. - Centro di alta specializzazione per il trattamento e lo studio della talassemia

1. Per l'attivazione di un centro di alta specializzazione per il trattamento e lo studio della talassemia, con connessa scuola di specializzazione, rispettivamente destinati, in via prioritaria, a pazienti e medici di altri Paesi del bacino del Mediterraneo e del Medio Oriente, e' autorizzata la spesa di 4.000.000 di euro per l'anno 2002 e di 10.000.000 di euro per ciascuno degli anni 2003 e 2004.

2. La sede del centro e della scuola di cui al comma 1 e' individuata dal Ministero della salute, di concerto con il Ministero dell'istruzione, dell'universita' e della ricerca e d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, tenuto conto delle esperienze di eccellenza maturate sul territorio nazionale nella cura e nell'insegnamento riguardanti la talassemia.

3. All'onere derivante dall'attuazione del presente articolo, determinato in 4.000.000 di euro per l'anno 2002 e in 10.000.000 di euro per ciascuno degli anni 2003 e 2004, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando, quanto a 3.499.666 euro per l'anno 2002, a 3.787.248 euro per l'anno 2003 e a 7.472.168 euro per l'anno 2004, l'accantonamento relativo al Ministero della salute, e quanto a 500.334 euro per l'anno 2002, a 6.212.752 euro per l'anno 2003 e a 2.527.832 euro per l'anno 2004, l'accantonamento relativo al Ministero dell'economia e delle finanze. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

### Art. 49. - Convenzione di Oviedo sui diritti dell'uomo e sulla biomedicina

1. Il termine per l'esercizio della delega previsto dall'articolo 3, comma 1, della legge 28 marzo 2001, n. 145, e' differito al 31 luglio 2003.

### Art. 50. - Modifica all'articolo 27 del decreto legislativo 30 luglio 1999, n. 300

1. All'articolo 27, comma 2, del decreto legislativo 30 luglio 1999, n. 300, come sostituito dall'articolo 3 del decreto-legge 12 giugno 2001, n. 217, convertito, con modificazioni, dalla legge 3 agosto 2001, n. 317, le parole: "acque minerali e termali," sono soppresse.

### Art. 51. - Tutela della salute dei non fumatori

1. E' vietato fumare nei locali chiusi, ad eccezione di:

- a) quelli privati non aperti ad utenti o al pubblico;
- b) quelli riservati ai fumatori e come tali contrassegnati.

1-bis. Il divieto di cui al comma 1 e' esteso anche alle aree all'aperto di pertinenza delle istituzioni del sistema educativo di istruzione e di formazione ((, nonche' alle pertinenze esterne delle strutture universitarie ospedaliere, presidi ospedalieri e IRCCS pediatrici e alle pertinenze esterne dei reparti di ginecologia e ostetricia, neonatologia e pediatria delle strutture universitarie ospedaliere e dei presidi ospedalieri e degli IRCCS)). ((20))

((1-ter Il divieto di cui al comma 1 e' esteso al conducente di autoveicoli, in sosta o in movimento, e ai passeggeri a bordo degli stessi in presenza di minori di anni diciotto e di donne in stato di gravidanza.))

((20))

2. Gli esercizi e i luoghi di lavoro di cui al comma 1, lettera b), devono essere dotati di impianti per la ventilazione ed il ricambio di aria regolarmente funzionanti. Al fine di garantire i livelli essenziali del diritto alla salute, le caratteristiche tecniche degli impianti per la ventilazione ed il ricambio di aria sono definite, entro centottanta giorni dalla data di pubblicazione della presente legge nella Gazzetta Ufficiale, con decreto del Presidente del Consiglio dei ministri di recepimento di un accordo tra lo Stato, le regioni e le province autonome, su proposta del Ministro della salute. Con lo stesso provvedimento sono definiti i locali riservati ai fumatori nonche' i modelli dei cartelli connessi all'attuazione delle disposizioni di cui al presente articolo.

3. Negli esercizi di ristorazione, ai sensi del comma 1, lettera b), devono essere adibiti ai non fumatori uno o piu' locali di superficie prevalente rispetto alla superficie complessiva di somministrazione dell'esercizio.

4. Con regolamento da emanare ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, e successive modificazioni, su proposta del Ministro della salute, possono essere individuati eventuali ulteriori luoghi chiusi nei quali sia consentito fumare, nel rispetto delle disposizioni di cui ai commi 1, 2 e 3. Tale regolamento deve prevedere che in tutte le strutture in cui le persone sono costrette a soggiornare non volontariamente devono essere previsti locali adibiti ai fumatori.

5. Alle infrazioni al divieto previsto dal presente articolo si applicano le sanzioni di cui all'articolo 7 della legge 11 novembre 1975, n. 584, come sostituito dall'articolo 52, comma 20, della legge 28 dicembre 2001, n. 448.

6. Al fine di consentire una adeguata attivita' di informazione, da attivare d'intesa con le organizzazioni di categoria piu' rappresentative, le disposizioni di cui ai commi 1, 2, primo periodo, 3 e 5 entrano in vigore decorso un anno dalla data di entrata in vigore del provvedimento di cui al comma 2.(6)

7. Entro centoventi giorni dalla data di pubblicazione della presente legge nella Gazzetta Ufficiale, con accordo sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, su proposta del Ministro della salute di concerto con i Ministri della giustizia e dell'interno, sono ridefinite le procedure per l'accertamento delle infrazioni, la relativa modulistica per il rilievo delle sanzioni nonche' l'individuazione dei soggetti legittimati ad elevare i relativi processi verbali, di quelli competenti a ricevere il rapporto sulle infrazioni accertate ai sensi dell'articolo 17 della legge 24 novembre 1981, n. 689, e di quelli deputati a irrogare le relative sanzioni.(7)

8. Le disposizioni di cui al presente articolo non comportano maggiori oneri a carico del bilancio dello Stato.

9. Rimangono in vigore, in quanto compatibili, le disposizioni di cui agli articoli 3, 5, 6, 8, 9, 10 e 11 della legge 11 novembre 1975, n. 584.

10. Restano ferme le disposizioni che disciplinano il divieto di fumo nei locali delle pubbliche amministrazioni.

10-bis. Il Ministero della salute esercita il monitoraggio, per i profili di competenza, sugli effetti dei prodotti succedanei dei prodotti da fumo, al fine di promuovere le necessarie iniziative anche normative a tutela della salute. PERIODO SOPPRESSO DAL D.L. 12 SETTEMBRE 2013, N. 104, CONVERTITO CON MODIFICAZIONI DALLA L. 8 NOVEMBRE 2013, N. 128.

10-ter. La pubblicita' di marchi di liquidi o ricariche per sigarette elettroniche contenenti nicotina e' consentita a condizione che riporti, in modo chiaramente visibile:

- a) la dicitura: 'presenza di nicotina';
- b) l'avvertimento sul rischio di dipendenza da nicotina.

10-quater. Entro sei mesi dalla data di entrata in vigore della presente disposizione, le emittenti radiotelevisive pubbliche e private e le agenzie pubblicitarie, unitamente ai rappresentanti della produzione, adottano un codice di autoregolamentazione sulle modalita' e sui contenuti dei messaggi pubblicitari relativi alle ricariche per sigarette elettroniche contenenti nicotina.

10-quinquies. E' vietata la pubblicita' di liquidi o ricariche per sigarette elettroniche contenenti nicotina che:

- a) sia trasmessa all'interno di programmi rivolti ai minori e nei quindici minuti precedenti e successivi alla trasmissione degli stessi;
- b) attribuisca efficacia o indicazioni terapeutiche che non siano espressamente riconosciute dal Ministero della salute;
- c) rappresenti minori di anni diciotto intenti all'utilizzo di sigarette elettroniche.

10-sexies. E' vietata la pubblicita' diretta o indiretta delle ricariche per sigarette elettroniche contenenti nicotina nei luoghi frequentati prevalentemente dai minori.

10-septies. E' vietata la pubblicita' radiotelevisiva di liquidi o ricariche per sigarette elettroniche contenenti nicotina nella fascia oraria dalle 16 alle 19.

10-octies. E' vietata in qualsiasi forma la pubblicita' di liquidi o ricariche per sigarette elettroniche contenenti nicotina:

- a) sulla stampa quotidiana e periodica destinata ai minori;
- b) nelle sale cinematografiche in occasione della proiezione di film destinati prevalentemente alla visione da parte dei minori.

10-novies. La violazione delle disposizioni di cui ai commi da 10-ter a 10-octies e' punita con la sanzione amministrativa consistente nel pagamento di una somma da euro 5.000 a euro 25.000. La sanzione e' raddoppiata per ogni ulteriore trasgressione.

10-decies. La sanzione di cui al comma 10-novies si applica altresi' alle industrie produttrici e ai responsabili delle emittenti radiotelevisive e degli organi di stampa nonche' ai proprietari delle sale cinematografiche.

------------- AGGIORNAMENTO (6) Il D.L. 9 novembre 2004, n. 266, convertito con modificazioni dalla L. 27 dicembre 2004, n. 306, ha disposto (con l'art. 19, comma 1) che il termine previsto dal comma 6 del presente articolo e' prorogato fino al 10 gennaio 2005. ------------- AGGIORNAMENTO (7) La L. 30 dicembre 2004, n. 311 ha disposto (con l'art. 1, comma 189) che le sanzioni amministrative per infrazioni al divieto di fumare, previste dal comma 7 del presente articolo sono aumentate del 10 per cento. ------------- AGGIORNAMENTO (20) Il D.Lgs. 12 gennaio 2016, n. 6, ha disposto (con l'art. 24, comma 5) che le presenti modifiche si applicano a decorrere dalla data di entrata in vigore del suindicato D.Lgs.

### Art. 52. - Modalita' dell'accertamento medico-legale effettuato dal Ministero della salute

1. Al decreto legislativo 30 giugno 1993, n. 266, concernente il riordinamento del Ministero della sanita', da intendersi ora riferito al Ministero della salute, dopo l'articolo 4 e' inserito il seguente: "Art. 4-bis. - (Modalita' dell'accertamento medico-legale effettuato dal Ministero della salute) - 1. Per la formulazione dei pareri medico-legali di propria competenza, il Ministero della salute ha facolta' di istituire, nel limite massimo di spesa di cui al comma 4, collegi medici con la partecipazione di esperti universitari od ospedalieri specialisti nelle varie discipline mediche, nei seguenti casi: a) quando sia richiesto un parere medico-legale dagli organi giudiziari o dalle Amministrazioni pubbliche, e sia necessario sottoporre l'interessato ad esame diretto; b) quando dagli atti rimessi al Ministero risulti una disparita' di giudizio tra gli organi competenti; c) quando negli atti si notino discordanze tra i risultati degli accertamenti medico-fiscali ed i giudizi diagnostico e medico-legale espressi; d) quando il giudizio diagnostico sia stato espresso in modo da non permettere una sicura applicazione delle tabelle A e B annesse alla legge 10 agosto 1950, n. 648, e successive modificazioni. 2. I collegi medici di cui al comma 1 sono composti dal dirigente dell'Ufficio medico-legale della Direzione generale delle professioni sanitarie e medico-legali, quale presidente, da un medico del predetto Ufficio, quale relatore, e da uno o piu' esperti scelti tra medici universitari od ospedalieri. 3. A ciascun esperto, per ogni giornata di seduta, e' corrisposto un compenso commisurato alle tariffe minime degli onorari per le prestazioni medico-chirurgiche stabilite dall'Ordine dei medici chirurghi e degli odontoiatri e vigenti al momento della prestazione. 4. Per i compensi delle prestazioni degli esperti di cui al comma 3 e' autorizzata la spesa annua massima di 3.693 euro a decorrere dall'anno 2002. 5. All'onere derivante dall'attuazione del presente articolo, determinato nella misura massima di 3.693 euro annui a decorrere dall'anno 2002, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero della salute. 6. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio".

### Art. 53. - Contributi straordinari a favore della provincia autonoma di Trento per lo svolgimento di un servizio di assistenza domiciliare integrata

1. Alla provincia autonoma di Trento e' assegnato un contributo straordinario di 2.000.000 di euro per l'anno 2002 e di 4.000.000 di euro per ciascuno degli anni 2003 e 2004 per lo svolgimento, in via sperimentale, di un servizio di assistenza domiciliare integrata.

2. All'onere derivante dall'attuazione del presente articolo, pari a 2.000.000 di euro per l'anno 2002 e 4.000.000 di euro per ciascuno degli anni 2003 e 2004, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2002-2004, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2002, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

3. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

## DISPOSIZIONI IN MATERIA DI TUTELA E SOSTEGNO DELLA PATERNITA' E DELLA MATERNITA'

### Art. 54. - Differimento del termine per l'emanazione di disposizioni correttive del testo unico delle disposizioni legislative in materia di tutela e sostegno della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151

1. Al comma 3 dell'articolo 15 della legge 8 marzo 2000, n. 53, le parole: "Entro un anno" sono sostituite dalle seguenti: "Entro due anni".

